@@ -6,9 +6,9 @@ from loguru import logger
 
 from .commands import (
     chat_arxiv,
-    chat_biorxiv,
+    chat_async_biorxiv,
+    chat_async_paper,
     chat_config,
-    chat_paper,
     chat_response,
     chat_reviewer,
 )
@@ -45,7 +45,7 @@ class RichHelpFormatter(argparse.HelpFormatter):
         super().__init__(*args, max_help_position=42, width=100, **kwargs)  # type: ignore
 
 
-def cli():
+def _cli():
     parser = RichArgParser(
         description="[red]chatre[/] Use ChatGPT to accelerate research",
         formatter_class=RichHelpFormatter,
@@ -69,11 +69,11 @@ def cli():
     chat_reviewer_command = chat_reviewer.add_subcommand(subparser)
     chat_arxiv_command = chat_arxiv.add_subcommnd(subparser)
     chat_response_command = chat_response.add_subcommand(subparser)
-    chat_paper_command = chat_paper.add_subcommand(subparser)
     chat_config_command = chat_config.add_subcommand(subparser)
-    chat_biorxiv_command = chat_biorxiv.add_subcommand(subparser)
-    args = parser.parse_args()
+    chat_async_biorxiv_command = chat_async_biorxiv.add_subcommand(subparser)
+    chat_async_paper_command = chat_async_paper.add_subcommand(subparser)
 
+    args = parser.parse_args()
     debug_format = "<green>{time:YYYY-MM-DD HH:mm:ss.SSS}</green> | <level>{level: <8}</level> | <cyan>{name}</cyan>:<cyan>{function}</cyan>:<cyan>{line}</cyan> - <level>{message}</level>"
     logger.remove()
 
@@ -94,9 +94,7 @@ def cli():
         parser.print_help()
         raise SystemExit
 
-    if args.subcommand == chat_paper_command:
-        chat_paper.cli(args)
-    elif args.subcommand == chat_arxiv_command:
+    if args.subcommand == chat_arxiv_command:
         chat_arxiv.cli(args)
     elif args.subcommand == chat_response_command:
         chat_response.cli(args)
@@ -104,11 +102,21 @@ def cli():
         chat_reviewer.cli(args)
     elif args.subcommand == chat_config_command:
         chat_config.cli(args)
-    elif args.subcommand == chat_biorxiv_command:
-        chat_biorxiv.cli(args)
+    elif args.subcommand == chat_async_biorxiv_command:
+        chat_async_biorxiv.cli(args)
+    elif args.subcommand == chat_async_paper_command:
+        chat_async_paper.cli(args)
     else:
         logger.error("Invalid subcommand")
         parser.print_help()
         raise SystemExit
 
     logger.success("Done")
+
+
+def cli():
+    try:
+        _cli()
+    except KeyboardInterrupt:
+        logger.info("Say youn again!")
+        raise SystemExit
